pub struct AtomicTick { /* private fields */ }Expand description
A tick that can be updated from multiple threads.
This has exactly the same semantics as Tick but can be updated
atomically. It’s used for summary ticks.
Implementations
Sourceimpl AtomicTick
impl AtomicTick
Sourcepub fn set(&self, new_tick: Tick)
pub fn set(&self, new_tick: Tick)
Sets a new value for the tick.
Note that this method takes &self and can therefore be called from
multiple threads. The tick is updated using relaxed ordering and is
therefore cheap to update on common architectures (x86-64, ARMv6 and
newer). However, be warned that, because it uses relaxed ordering, a
full mutex lock or similar barrier is required if you need to coordinate
the synchronization of this value with other memory locations.